@@ -9,22 +9,27 @@ from urllib.parse import quote
 from simple_term_menu import TerminalMenu
 import platform
 
+import copilot.history as history
+
 
 def main():
     parser = argparse.ArgumentParser(prog='copilot', description='Terminal Copilot')
     parser.add_argument('command', type=str, nargs='+',
                         help='Describe the command you are looking for.')
-    parser.add_argument('-a', '--with-aliases', action='store_true',
-                        help='include aliases in the prompt')
+    parser.add_argument('-a', '--alias', action='store_true',
+                        help='Include aliases in the prompt. Note: This feature may potentially send sensitive information to OpenAI.')
     parser.add_argument('-v', '--verbose', action='store_true',
                         help='increase output verbosity')
+    parser.add_argument('-g', '--git', action='store_true',
+                        help='Include git info if available')
+    parser.add_argument('-hist', '--history', action='store_true',
+                        help='Include terminal history in the prompt. Note: This feature may potentially send sensitive information to OpenAI and increase the number of tokens used.')
 
     args = parser.parse_args()
 
     if args.verbose:
         print("Verbose mode enabled")
 
-    # run history -40 to get the last 40 commands
     # TODO to get more terminal context to work with..
     # TODO save history of previous user questions and answers
 
@@ -47,13 +52,15 @@ The user is currently in the following directory:
 {subprocess.run(["pwd"], capture_output=True).stdout.decode("utf-8")}
 That directory contains the following files:
 {subprocess.run(["ls"], capture_output=True).stdout.decode("utf-8")}
+{history.get_history() if args.history else ""}
 The user has several environment variables set, some of which are:
 {environs}
+{git_info() if args.git else ""}
 """
-    if args.with_aliases:
+    if args.alias:
         prompt += f"""
 The user has the following aliases set:
-{subprocess.run(["alias"], capture_output=True, shell=True).stdout.decode("utf-8")}
+{subprocess.run(["history"], capture_output=True, shell=True).stdout.decode("utf-8")}
 """
     prompt += """
 
@@ -76,13 +83,14 @@ The command the user is looking for is:
     cmd = request_cmds(prompt, n=1)[0]
     show_command_options(prompt, cmd)
 
+
 def show_command_options(prompt, cmd):
     print(f"\033[94m> {cmd}\033[0m")
     options = ["execute", "copy", "explainshell", "show more options"]
     terminal_menu = TerminalMenu(options)
     menu_entry_index = terminal_menu.show()
     if menu_entry_index == 0:
-        os.system(cmd)
+        execute(cmd)
     elif menu_entry_index == 1:
         print("> copied")
         pyperclip.copy(cmd)
@@ -93,6 +101,12 @@ def show_command_options(prompt, cmd):
     elif menu_entry_index == 3:
         show_more_cmd_options(prompt)
 
+
+def execute(cmd):
+    os.system(cmd)
+    history.save(cmd)
+
+
 def show_more_cmd_options(prompt):
     cmds = request_cmds(prompt, n=5)
     print("Here are more options:")
@@ -124,3 +138,19 @@ def request_cmds(prompt, n=1):
 
 def strip_all_whitespaces_from(choices):
     return [choice.text.strip() for choice in choices]
+
+
+def git_info():
+    git_installed = subprocess.run(["which", "git"], capture_output=True).returncode == 0
+    if os.path.exists(".git") and git_installed:
+        return f"""
+User is in a git repo.
+Branches are:
+{subprocess.run(["git", "branch"], capture_output=True).stdout.decode("utf-8")}
+Last 3 git history entries:
+{subprocess.run(["git", "log", "-n3", "--oneline"], capture_output=True).stdout.decode("utf-8")}
+Short git status:
+{subprocess.run(["git", "status", "-s"], capture_output=True).stdout.decode("utf-8")}
+"""
+    else:
+        return ""
